==> deepin-polkit-agent-5.4.16-1.src.tar.gz: dde-polkit-agent-5.4.16/translations/dde-polkit-agent_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="96"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>Прст је пребрзо склоњен, молимо не подижите до обавештења</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="98"/>
        <source>Verification failed, two chances left</source>
        <translation>Неуспешна верификација, имате још 2 покушаја</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="118"/>
        <location filename="../AuthDialog.cpp" line="303"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Потврди</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="213"/>
        <source>You are required to change your password immediately (password expired)</source>
        <translation>Потребно је да хитно промените лозинку (лозинка је истекла)</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="278"/>
        <source>Wrong password, only one chance left</source>
        <translation>Погрешна лозинка, имате још један покушај</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="281"/>
        <source>Wrong password, two chances left</source>
        <translation>Погрешна лозинка, имате још два покушаја</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="285"/>
        <source>Wrong password</source>
        <translation>Погрешна лозинка</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="302"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
</context>
</TS>

==> deepin-polkit-agent-5.4.17-1.src.tar.gz: dde-polkit-agent-5.4.17/translations/dde-polkit-agent_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="98"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>Прст је пребрзо склоњен, молимо не подижите до обавештења</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="100"/>
        <source>Verification failed, two chances left</source>
        <translation>Неуспешна верификација, имате још 2 покушаја</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="120"/>
        <location filename="../AuthDialog.cpp" line="326"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Потврди</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="227"/>
        <source>You are required to change your password immediately (password expired)</source>
        <translation>Потребно је да хитно промените лозинку (лозинка је истекла)</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="299"/>
        <source>Locked, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong password, only one chance left</source>
        <translation type="vanished">Погрешна лозинка, имате још један покушај</translation>
    </message>
    <message>
        <source>Wrong password, two chances left</source>
        <translation type="vanished">Погрешна лозинка, имате још два покушаја</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="301"/>
        <source>Wrong password</source>
        <translation>Погрешна лозинка</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="325"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
</context>
</TS>
